==> hypercrud.server-0.2.0-20171004.002105-18.jar: hypercrud/server/internal.clj <==
(ns hypercrud.server.internal
  (:require [hypercrud.types.DbId]
            [hypercrud.types.DbVal]
            [hypercrud.types.DbError]
            [hypercrud.types.EntityRequest]
            [hypercrud.types.QueryRequest]
            [hypercrud.types.URI])
  (:import (hypercrud.types.DbId DbId DbIdTransitHandler DbIdTransitReader)
           (hypercrud.types.DbVal DbVal DbValTransitHandler DbValTransitReader)
           (hypercrud.types.DbError DbError DbErrorTransitHandler DbErrorTransitReader)
           (hypercrud.types.EntityRequest EntityRequest EntityRequestTransitHandler EntityRequestTransitReader)
           (hypercrud.types.QueryRequest QueryRequest QueryRequestTransitHandler QueryRequestTransitReader)
           (com.cognitect.transit WriteHandler ReadHandler)
           (java.net URI)))


(def transit-read-handlers {"DbId" (DbIdTransitReader.)
                            "DbVal" (DbValTransitReader.)
                            "DbError" (DbErrorTransitReader.)
                            "QReq" (QueryRequestTransitReader.)
                            "EReq" (EntityRequestTransitReader.)
                            "r" (reify ReadHandler (fromRep [_ v] (URI. v)))})

(def transit-write-handlers {DbId (DbIdTransitHandler.)
                             DbVal (DbValTransitHandler.)
                             DbError (DbErrorTransitHandler.)
                             QueryRequest (QueryRequestTransitHandler.)
                             EntityRequest (EntityRequestTransitHandler.)})

==> hypercrud.server-0.2.0-20171027.151744-25.jar: hypercrud/server/internal.clj <==
(ns hypercrud.server.internal
  (:require [hypercrud.types.DbVal]
            [hypercrud.types.DbError]
            [hypercrud.types.Entity]
            [hypercrud.types.EntityRequest]
            [hypercrud.types.QueryRequest]
            [hypercrud.types.URI])
  (:import (hypercrud.types.DbVal DbVal DbValTransitHandler DbValTransitReader)
           (hypercrud.types.DbError DbError DbErrorTransitHandler DbErrorTransitReader)
           (hypercrud.types.Entity Entity EntityTransitHandler EntityTransitReader)
           (hypercrud.types.EntityRequest EntityRequest EntityRequestTransitHandler EntityRequestTransitReader)
           (hypercrud.types.QueryRequest QueryRequest QueryRequestTransitHandler QueryRequestTransitReader)
           (com.cognitect.transit WriteHandler ReadHandler)
           (java.net URI)))


(def transit-read-handlers {"DbVal" (DbValTransitReader.)
                            "DbError" (DbErrorTransitReader.)
                            "Entity" (EntityTransitReader.)
                            "QReq" (QueryRequestTransitReader.)
                            "EReq" (EntityRequestTransitReader.)
                            "r" (reify ReadHandler (fromRep [_ v] (URI. v)))})

(def transit-write-handlers {DbVal (DbValTransitHandler.)
                             DbError (DbErrorTransitHandler.)
                             Entity (EntityTransitHandler.)
                             QueryRequest (QueryRequestTransitHandler.)
                             EntityRequest (EntityRequestTransitHandler.)})
